@@ -43,7 +43,7 @@
 
 #include <KAboutData>
 #include <KConfigGroup>
-#include <KIOWidgets/KRun>
+#include <KRun>
 #include <KIO/CopyJob>
 #include <KJobUiDelegate>
 #include <KLocalizedString>
@@ -69,12 +69,12 @@ ApplyProgressDialog::ApplyProgressDialog(QWidget* parent, OperationRunner& orunn
     m_ProgressDialogWidget(new ApplyProgressDialogWidget(this)),
     m_ProgressDetailsWidget(new ApplyProgressDetailsWidget(this)),
     m_OperationRunner(orunner),
-    m_Report(NULL),
+    m_Report(nullptr),
     m_SavedParentTitle(mainWindow(this)->windowTitle()),
     m_Timer(this),
     m_Time(),
-    m_CurrentOpItem(NULL),
-    m_CurrentJobItem(NULL),
+    m_CurrentOpItem(nullptr),
+    m_CurrentJobItem(nullptr),
     m_LastReportUpdate(0)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -117,18 +117,18 @@ ApplyProgressDialog::~ApplyProgressDialog()
 
 void ApplyProgressDialog::setupConnections()
 {
-    connect(&operationRunner(), SIGNAL(progressSub(int)), &dialogWidget().progressSub(), SLOT(setValue(int)));
-    connect(&operationRunner(), SIGNAL(finished()), SLOT(onAllOpsFinished()));
-    connect(&operationRunner(), SIGNAL(cancelled()), SLOT(onAllOpsCancelled()));
-    connect(&operationRunner(), SIGNAL(error()), SLOT(onAllOpsError()));
-    connect(&operationRunner(), SIGNAL(opStarted(int, Operation*)), SLOT(onOpStarted(int, Operation*)));
-    connect(&operationRunner(), SIGNAL(opFinished(int, Operation*)), SLOT(onOpFinished(int, Operation*)));
-    connect(&timer(), SIGNAL(timeout()), SLOT(onSecondElapsed()));
-    connect(&detailsWidget().buttonSave(), SIGNAL(clicked()), SLOT(saveReport()));
-    connect(&detailsWidget().buttonBrowser(), SIGNAL(clicked()), SLOT(browserReport()));
-    connect(dialogButtonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(dialogButtonBox, SIGNAL(rejected()), this, SLOT(reject()));
-    connect(detailsButton, SIGNAL(clicked()), this, SLOT(toggleDetails()));
+    connect(&operationRunner(), &OperationRunner::progressSub, &dialogWidget().progressSub(), &QProgressBar::setValue);
+    connect(&operationRunner(), &OperationRunner::finished, this, &ApplyProgressDialog::onAllOpsFinished);
+    connect(&operationRunner(), &OperationRunner::cancelled, this, &ApplyProgressDialog::onAllOpsCancelled);
+    connect(&operationRunner(), &OperationRunner::error, this, &ApplyProgressDialog::onAllOpsError);
+    connect(&operationRunner(), &OperationRunner::opStarted, this, &ApplyProgressDialog::onOpStarted);
+    connect(&operationRunner(), &OperationRunner::opFinished, this, &ApplyProgressDialog::onOpFinished);
+    connect(&timer(), &QTimer::timeout, this, &ApplyProgressDialog::onSecondElapsed);
+    connect(&detailsWidget().buttonSave(), &QPushButton::clicked, this, &ApplyProgressDialog::saveReport);
+    connect(&detailsWidget().buttonBrowser(), &QPushButton::clicked, this, &ApplyProgressDialog::browserReport);
+    connect(dialogButtonBox, &QDialogButtonBox::accepted, this, &ApplyProgressDialog::accept);
+    connect(dialogButtonBox, &QDialogButtonBox::rejected, this, &ApplyProgressDialog::reject);
+    connect(detailsButton, &QPushButton::clicked, this, &ApplyProgressDialog::toggleDetails);
 }
 
 /** Shows the dialog */
@@ -158,14 +158,14 @@ void ApplyProgressDialog::show()
 void ApplyProgressDialog::resetReport()
 {
     delete m_Report;
-    m_Report = new Report(NULL);
+    m_Report = new Report(nullptr);
 
     detailsWidget().editReport().clear();
     detailsWidget().editReport().setCursorWidth(0);
     detailsWidget().buttonSave().setEnabled(false);
     detailsWidget().buttonBrowser().setEnabled(false);
 
-    connect(&report(), SIGNAL(outputChanged()), SLOT(updateReport()));
+    connect(&report(), &Report::outputChanged, this, &ApplyProgressDialog::updateReportUnforced);
 }
 
 void ApplyProgressDialog::closeEvent(QCloseEvent* e)
@@ -253,6 +253,11 @@ void ApplyProgressDialog::allOpsDone(const QString& msg)
     setStatus(msg);
 }
 
+void ApplyProgressDialog::updateReportUnforced()
+{
+    updateReport(false);
+}
+
 void ApplyProgressDialog::updateReport(bool force)
 {
     // Rendering the HTML in the QTextEdit is extremely expensive. So make sure not to do that
@@ -277,8 +282,8 @@ void ApplyProgressDialog::onOpStarted(int num, Operation* op)
     dialogWidget().progressSub().setValue(0);
     dialogWidget().progressSub().setRange(0, op->totalProgress());
 
-    connect(op, SIGNAL(jobStarted(Job*, Operation*)), SLOT(onJobStarted(Job*, Operation*)));
-    connect(op, SIGNAL(jobFinished(Job*, Operation*)), SLOT(onJobFinished(Job*, Operation*)));
+    connect(op, &Operation::jobStarted, this, &ApplyProgressDialog::onJobStarted);
+    connect(op, &Operation::jobFinished, this, &ApplyProgressDialog::onJobFinished);
 }
 
 void ApplyProgressDialog::onJobStarted(Job* job, Operation* op)
@@ -286,7 +291,7 @@ void ApplyProgressDialog::onJobStarted(Job* job, Operation* op)
     for (qint32 i = 0; i < dialogWidget().treeTasks().topLevelItemCount(); i++) {
         QTreeWidgetItem* item = dialogWidget().treeTasks().topLevelItem(i);
 
-        if (item == NULL || reinterpret_cast<const Operation*>(item->data(0, Qt::UserRole).toULongLong()) != op)
+        if (item == nullptr || reinterpret_cast<const Operation*>(item->data(0, Qt::UserRole).toULongLong()) != op)
             continue;
 
         QTreeWidgetItem* child = new QTreeWidgetItem();
@@ -305,7 +310,7 @@ void ApplyProgressDialog::onJobFinished(Job* job, Operation* op)
     if (currentJobItem())
         currentJobItem()->setIcon(0, job->statusIcon());
 
-    setCurrentJobItem(NULL);
+    setCurrentJobItem(nullptr);
 
     const int current = dialogWidget().progressTotal().value();
     dialogWidget().progressTotal().setValue(current + 1);
@@ -321,7 +326,7 @@ void ApplyProgressDialog::onOpFinished(int num, Operation* op)
         currentOpItem()->setIcon(0, op->statusIcon());
     }
 
-    setCurrentOpItem(NULL);
+    setCurrentOpItem(nullptr);
 
     setStatus(op->description());
 
