@@ -76,13 +76,13 @@ void DevicePropsDialog::setupDialog()
     okButton->setEnabled(false);
     cancelButton->setFocus();
     cancelButton->setDefault(true);
-    connect(dialogButtonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(dialogButtonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(dialogButtonBox, &QDialogButtonBox::accepted, this, &DevicePropsDialog::accept);
+    connect(dialogButtonBox, &QDialogButtonBox::rejected, this, &DevicePropsDialog::reject);
 
     QString type = QStringLiteral("---");
     QString maxPrimaries = QStringLiteral("---");
 
-    if (device().partitionTable() != NULL) {
+    if (device().partitionTable() != nullptr) {
         type = (device().partitionTable()->isReadOnly())
                ? i18nc("@label device", "%1 (read only)", device().partitionTable()->typeName())
                : device().partitionTable()->typeName();
@@ -137,9 +137,9 @@ void DevicePropsDialog::setupDialog()
 
 void DevicePropsDialog::setupConnections()
 {
-    connect(&dialogWidget().radioSectorBased(), SIGNAL(toggled(bool)), SLOT(setDirty(bool)));
-    connect(&dialogWidget().radioCylinderBased(), SIGNAL(toggled(bool)), SLOT(setDirty(bool)));
-    connect(&dialogWidget().buttonSmartMore(), SIGNAL(clicked(bool)), SLOT(onButtonSmartMore(bool)));
+    connect(&dialogWidget().radioSectorBased(), &QRadioButton::toggled, this, &DevicePropsDialog::setDirty);
+    connect(&dialogWidget().radioCylinderBased(), &QRadioButton::toggled, this, &DevicePropsDialog::setDirty);
+    connect(&dialogWidget().buttonSmartMore(), &QPushButton::clicked, this, &DevicePropsDialog::onButtonSmartMore);
 }
 
 void DevicePropsDialog::setDirty(bool)
