@@ -1,5 +1,7 @@
 /*************************************************************************
  *  Copyright (C) 2009, 2010 by Volker Lanz <vl@fidra.de>                *
+ *  Copyright (C) 2015 by Teo Mrnjavac <teo@kde.org>                     *
+ *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
  *  modify it under the terms of the GNU General Public License as       *
@@ -27,6 +29,8 @@
 #include <KConfigGroup>
 #include <KSharedConfig>
 
+#include <QDialogButtonBox>
+
 EditMountPointDialog::EditMountPointDialog(QWidget* parent, Partition& p) :
     QDialog(parent),
     m_Partition(p),
@@ -39,6 +43,15 @@ EditMountPointDialog::EditMountPointDialog(QWidget* parent, Partition& p) :
 
     KConfigGroup kcg(KSharedConfig::openConfig(), "editMountPointDialog");
     restoreGeometry(kcg.readEntry<QByteArray>("Geometry", QByteArray()));
+
+    QDialogButtonBox* dbb = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel,
+                                                  Qt::Horizontal,
+                                                  this );
+    mainLayout->addWidget(dbb);
+    connect(dbb, &QDialogButtonBox::accepted,
+            this, &EditMountPointDialog::accept);
+    connect(dbb, &QDialogButtonBox::rejected,
+            this, &EditMountPointDialog::reject);
 }
 
 /** Destroys an EditMOuntOptionsDialog instance */
