@@ -99,6 +99,9 @@ MainWindow::MainWindow(QWidget* parent) :
 {
     setupObjectNames();
     setupUi(this);
+    connect(&m_ListDevices->listDevices(), &QListWidget::customContextMenuRequested, this, &MainWindow::listDevicesContextMenuRequested);
+    connect(&m_TreeLog->treeLog(), &QTreeWidget::customContextMenuRequested, this, &MainWindow::treeLogContextMenuRequested);
+    connect(&m_ListOperations->listOperations(), &QListWidget::customContextMenuRequested, this, &MainWindow::listOperationsContextMenuRequested);
     init();
 }
 
@@ -179,7 +182,7 @@ void MainWindow::changeEvent(QEvent* event)
 void MainWindow::setupActions()
 {
     // File actions
-    KStandardAction::quit(this, SLOT(close()), actionCollection());
+    KStandardAction::quit(this, &MainWindow::close, actionCollection());
 
     // Edit actions
     QAction* undoOperation = actionCollection()->addAction(QStringLiteral("undoOperation"));
@@ -249,7 +252,7 @@ void MainWindow::setupActions()
     smartStatusDevice->setStatusTip(i18nc("@info:status", "Show the device's SMART status if supported"));
 
     QAction* propertiesDevice = actionCollection()->addAction(QStringLiteral("propertiesDevice"));
-    connect(propertiesDevice, &QAction::triggered, this, &MainWindow::onPropertiesDevice2);
+    connect(propertiesDevice, &QAction::triggered, [this] {onPropertiesDevice({});});
     propertiesDevice->setEnabled(false);
     propertiesDevice->setText(i18nc("@action:inmenu", "Properties"));
     propertiesDevice->setToolTip(i18nc("@info:tooltip", "Show device properties dialog"));
@@ -377,7 +380,7 @@ void MainWindow::setupActions()
     actionCollection()->addAction(QStringLiteral("toggleDockLog"), dockLog().toggleViewAction());
 
     // Settings Actions
-    KStandardAction::preferences(this, SLOT(onConfigureOptions()), actionCollection());
+    KStandardAction::preferences(this, &MainWindow::onConfigureOptions, actionCollection());
 
     // Log Actions
     QAction* clearLog = actionCollection()->addAction(QStringLiteral("clearLog"));
@@ -559,28 +562,28 @@ void MainWindow::updateWindowTitle()
     setWindowTitle(title);
 }
 
-void MainWindow::on_m_ListOperations_contextMenuRequested(const QPoint& pos)
+void MainWindow::listOperationsContextMenuRequested(const QPoint& pos)
 {
     QMenu* menu = static_cast<QMenu*>(guiFactory()->container(QStringLiteral("edit"), this));
 
     if (menu)
-        menu->exec(pos);
+        menu->exec(m_ListOperations->listOperations().viewport()->mapToGlobal(pos));
 }
 
-void MainWindow::on_m_TreeLog_contextMenuRequested(const QPoint& pos)
+void MainWindow::treeLogContextMenuRequested(const QPoint& pos)
 {
     QMenu* menu = static_cast<QMenu*>(guiFactory()->container(QStringLiteral("log"), this));
 
     if (menu)
-        menu->exec(pos);
+        menu->exec(m_TreeLog->treeLog().viewport()->mapToGlobal(pos));
 }
 
-void MainWindow::on_m_ListDevices_contextMenuRequested(const QPoint& pos)
+void MainWindow::listDevicesContextMenuRequested(const QPoint& pos)
 {
     QMenu* menu = static_cast<QMenu*>(guiFactory()->container(QStringLiteral("device"), this));
 
     if (menu)
-        menu->exec(pos);
+        menu->exec(m_ListDevices->listDevices().viewport()->mapToGlobal(pos));
 }
 
 void MainWindow::on_m_PartitionManagerWidget_contextMenuRequested(const QPoint& pos)
@@ -1066,11 +1069,6 @@ void MainWindow::onSmartStatusDevice()
     }
 }
 
-void MainWindow::onPropertiesDevice2()
-{
-    onPropertiesDevice({});
-}
-
 void MainWindow::onPropertiesDevice(const QString&)
 {
     Q_ASSERT(pmWidget().selectedDevice());
@@ -1106,8 +1104,10 @@ static KLocalizedString checkSupportInNode(const PartitionNode* parent)
         if (p == nullptr)
             continue;
 
-        if (node->children().size() > 0)
+        if (node->children().size() > 0 && !rval.isEmpty())
             rval = kxi18n("%1%2").subs(rval).subs(checkSupportInNode(node));
+        else
+            rval = checkSupportInNode(node);
 
         if (!p->fileSystem().supportToolFound() && !p->fileSystem().supportToolName().name.isEmpty())
             rval = kxi18n("%1%2").subs(rval).subs(kxi18n("<tr>"
@@ -1132,7 +1132,7 @@ void MainWindow::checkFileSystemSupport()
 
     foreach(const Device * d, operationStack().previewDevices()) {
         supportInNode = checkSupportInNode(d->partitionTable());
-        if (supportInNode.toString() != QString()) {
+        if (!supportInNode.isEmpty()) {
             missingSupportTools = true;
             supportList = kxi18n("%1%2").subs(supportList).subs(supportInNode);
         }
