@@ -40,18 +40,18 @@ class PartTableWidget : public PartWidgetBase
 
 public:
     PartTableWidget(QWidget* parent);
-    virtual qint32 borderWidth() const {
+    qint32 borderWidth() const override {
         return 0;    /**< @return border width */
     }
-    virtual qint32 borderHeight() const {
+    qint32 borderHeight() const override {
         return 0;    /**< @return border height */
     }
 
 public:
     void setPartitionTable(const PartitionTable* ptable);
 
-    PartWidget* activeWidget(); /**< @return the active widget or NULL if none */
-    const PartWidget* activeWidget() const; /**< @return the active widget or NULL if none */
+    PartWidget* activeWidget(); /**< @return the active widget or nullptr if none */
+    const PartWidget* activeWidget() const; /**< @return the active widget or nullptr if none */
 
     void setActiveWidget(PartWidget* partWidget);
     void setActivePartition(const Partition* p);
@@ -68,9 +68,9 @@ Q_SIGNALS:
     void itemDoubleClicked(const PartWidget*);
 
 protected:
-    void resizeEvent(QResizeEvent* event);
-    void mousePressEvent(QMouseEvent* event);
-    void mouseDoubleClickEvent(QMouseEvent* event);
+    void resizeEvent(QResizeEvent* event) override;
+    void mousePressEvent(QMouseEvent* event) override;
+    void mouseDoubleClickEvent(QMouseEvent* event) override;
 
     const PartitionTable* partitionTable() const {
         return m_PartitionTable;
