@@ -1,5 +1,6 @@
 /*************************************************************************
  *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
+ *  Copyright (C) 2016 by Teo Mrnjavac <teo@kde.org>                     *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
  *  modify it under the terms of the GNU General Public License as       *
@@ -28,8 +29,6 @@
 */
 class SizeDialogWidget : public QWidget, public Ui::SizeDialogWidgetBase
 {
-    Q_OBJECT
-
 public:
     SizeDialogWidget(QWidget* parent) : QWidget(parent), Ui::SizeDialogWidgetBase() {
         setupUi(this);
@@ -81,6 +80,16 @@ public:
         return *m_ComboFileSystem;
     }
 
+    QCheckBox& checkBoxEncrypt() {
+        Q_ASSERT(m_CheckBoxEncrypt);
+        return *m_CheckBoxEncrypt;
+    }
+
+    KNewPasswordWidget& editPassphrase() {
+        Q_ASSERT(m_EditPassphrase);
+        return *m_EditPassphrase;
+    }
+
     QLabel& textLabel() {
         Q_ASSERT(m_LabelTextLabel);
         return *m_LabelTextLabel;
@@ -100,27 +109,31 @@ public:
 
     void hideRole() {
         delete m_LabelRole;
-        m_LabelRole = NULL;
+        m_LabelRole = nullptr;
         delete m_RadioPrimary;
-        m_RadioPrimary = NULL;
+        m_RadioPrimary = nullptr;
         delete m_RadioExtended;
-        m_RadioExtended = NULL;
+        m_RadioExtended = nullptr;
         delete m_RadioLogical;
-        m_RadioLogical = NULL;
+        m_RadioLogical = nullptr;
     }
     void hideFileSystem() {
         delete m_LabelFileSystem;
-        m_LabelFileSystem = NULL;
+        m_LabelFileSystem = nullptr;
         delete m_ComboFileSystem;
-        m_ComboFileSystem = NULL;
+        m_ComboFileSystem = nullptr;
+        delete m_CheckBoxEncrypt;
+        m_CheckBoxEncrypt = nullptr;
+        delete m_EditPassphrase;
+        m_EditPassphrase = nullptr;
     }
     void hideLabel() {
         delete m_LabelTextLabel;
-        m_LabelTextLabel = NULL;
+        m_LabelTextLabel = nullptr;
         delete m_EditLabel;
-        m_EditLabel = NULL;
+        m_EditLabel = nullptr;
         delete m_LabelTextNoSetLabel;
-        m_LabelTextNoSetLabel = NULL;
+        m_LabelTextNoSetLabel = nullptr;
     }
 };
 
